@@ -15,9 +15,9 @@
  * passwords being leaked to e.g. other system users. Take extra care when
  * the webserver is shared with untrusted users.
  *
- * @copyright &copy; 2000-2006 The SquirrelMail Project Team
+ * @copyright &copy; 2000-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: config_default.php,v 1.84.2.20 2006/10/07 11:58:42 tokul Exp $
+ * @version $Id: config_default.php 12302 2007-03-04 02:07:59Z jervfors $
  * @package squirrelmail
  * @subpackage config
  */
@@ -447,19 +447,24 @@ $noselect_fix_enable = false;
  *
  *   It is a possible security hole to have a writable directory
  *   under the web server's root directory (ex: /home/httpd/html).
- *   For this reason, it is possible to put the data directory
- *   anywhere you would like. The path name can be absolute or
- *   relative (to the config directory). It doesn't matter. Here
- *   are two examples:
+ *   It is possible to put the data directory anywhere you would like;
+ *   it is strongly advised that it is directly web-accessible.
+ *
+ *   The path name can be absolute or relative (to the config directory).
+ *   If it is relative, it must use the SM_PATH constant.
+ *   Here are two examples:
  *
  * Absolute:
- *   $data_dir = '/usr/local/squirrelmail/data/';
+ *   $data_dir = '/var/local/squirrelmail/data/';
  *
  * Relative (to main SM directory):
  *   $data_dir = SM_PATH . 'data/';
+ *   (NOT recommended: you need to secure apache to make sure these
+ *   files are not world readable)
+ *
  * @global string $data_dir
  */
-$data_dir = SM_PATH . 'data/';
+$data_dir = '/var/www/html/squirrelmail/data/';
 
 /**
  * Attachments directory
@@ -472,12 +477,12 @@ $data_dir = SM_PATH . 'data/';
  *      list files in this directory. Confidential data might be laying
  *      around there.
  *    + Since the webserver is not able to list the files in the content
- *       is also impossible for the webserver to delete files lying around 
- *       there for too long.
+ *      is also impossible for the webserver to delete files lying around 
+ *      there for too long.
  *    + It should probably be another directory than data_dir.
  * @global string $attachment_dir
  */
-$attachment_dir = $data_dir;
+$attachment_dir = '/var/www/html/squirrelmail/data/';
 
 /**
  * Hash level used for data directory.
@@ -909,13 +914,13 @@ $motd = "";
 
 /*** Database ***/
 /**
- * Read doc/database.txt in order to get more information 
+ * Read the administrator's manual in order to get more information 
  * about these settings.
  */
 /**
  * Database-driven private addressbooks
  *   DSN (Data Source Name) for a database where the private
- *   addressbooks are stored.  See doc/db-backend.txt for more info.
+ *   addressbooks are stored.  See the administrator's manual for more info.
  *   If it is not set, the addressbooks are stored in files
  *   in the data dir.
  *   The DSN is in the format: mysql://user:pass@hostname/dbname
