@@ -5,9 +5,9 @@
  *
  * This implements all functions that manipulate mailboxes
  *
- * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_mailbox.php,v 1.172.2.28 2006/10/07 12:58:41 tokul Exp $
+ * @version $Id: imap_mailbox.php 12314 2007-03-06 14:55:41Z kink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -547,14 +547,16 @@ function sqimap_mailbox_option_list($imap_stream, $show_selected = 0, $folder_sk
  */
 function mailtree_sort(&$lsub) {
     if(!is_array($lsub)) return;
-
+    
+    global $delimiter;
+    
     foreach($lsub as $index => $mailbox)
-        $lsub[$index] = str_replace('.',' -#- ',$lsub[$index]);
+        $lsub[$index] = str_replace($delimiter,' -#- ',$lsub[$index]);
 
     usort($lsub, 'user_strcasecmp');
 
     foreach($lsub as $index => $mailbox)
-        $lsub[$index] = str_replace(' -#- ','.',$lsub[$index]);
+        $lsub[$index] = str_replace(' -#- ',$delimiter,$lsub[$index]);
 }
 
 /**
@@ -607,7 +609,7 @@ function sqimap_mailbox_list($imap_stream, $force=false) {
         }
         /* remove duplicates */
         $sorted_lsub_ary = array_unique($sorted_lsub_ary);
-
+       
         /* natural sort mailboxes */
         if (isset($sorted_lsub_ary)) {
             mailtree_sort($sorted_lsub_ary);
@@ -805,4 +807,3 @@ function sqimap_mailbox_list_all($imap_stream) {
     return $boxes;
 }
 
-?>
\ No newline at end of file
