@@ -6,9 +6,9 @@
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: mailbox_display.php,v 1.321.2.37 2006/10/20 08:59:34 kink Exp $
+ * @version $Id: mailbox_display.php 12364 2007-05-03 15:02:47Z kink $
  * @package squirrelmail
  */
 
@@ -261,7 +261,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                     $td_str .= _("A");
                     $stuff = true;
                 }
-                if ($msg['TYPE0'] == 'multipart') {
+                if ($msg['TYPE0'] == 'multipart' && $msg['TYPE1'] == 'mixed') {
                     $td_str .= '+';
                     $stuff = true;
                 }
@@ -451,10 +451,10 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 $id   = get_thread_sort($imapConnection);
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
-                    echo '<b><small><center><font color=red>' .
+                    echo '<b><small><center><font color="red">' .
                         _("Thread sorting is not supported by your IMAP server.") . '<br />' .
                         _("Please contact your system administrator and report this error.") .
-                        '</center></small></b>';
+                        '</font></center></small></b>';
                     $thread_sort_messages = 0;
                     $msort = $msgs = array();
                 } else {
@@ -466,10 +466,10 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 $id   = sqimap_get_sort_order($imapConnection, $sort, $mbxresponse);
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
-                    echo '<b><small><center><font color=red>' .
+                    echo '<b><small><center><font color="red">' .
                         _( "Server-side sorting is not supported by your IMAP server.") . '<br />' .
                         _("Please contact your system administrator and report this error.") .
-                        '</center></small></b>';
+                        '</font></center></small></b>';
                     $sort = $server_sort_order;
                     $allow_server_sort = FALSE;
                     $msort = $msgs = array();
@@ -506,12 +506,18 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     $msg_cnt_str = get_msgcnt_str($start_msg, $end_msg, $num_msgs);
 
     do_hook('mailbox_index_before');
+
+    $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+    $form_name = "FormMsgs" . $safe_name;
+    echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n" .
+        '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
+        '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
+    
     echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
     echo '<tr><td>';
 
     mail_message_listing_beginning($imapConnection, $mailbox, $sort,
                                   $msg_cnt_str, $paginator_str, $start_msg);
-    echo '</td></tr>';
     /* line between the button area and the list */
     echo '<tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
@@ -519,15 +525,17 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
     echo '     <tr><td>';
     echo '       <table width="100%" cellpadding="1" cellspacing="0" align="center" border="0" bgcolor="'.$color[5].'">';
-    echo '<tr><td>';
     printHeader($mailbox, $srt, $color, !$thread_sort_messages);
 
     displayMessageArray($imapConnection, $num_msgs, $start_msg,
                         $msort, $mailbox, $sort, $color, $show_num,0,0);
-    echo '</td></tr></table></td></tr></table>';
+    echo '</table></td></tr></table>';
 
     mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color);
-    echo '</td></tr></table>';
+    echo '</table>';
+
+    echo "\n</form>\n\n";
+    
     //$t = elapsed($start);
     //echo("elapsed time = $t seconds\n");
 }
@@ -693,21 +701,10 @@ function mail_message_listing_beginning ($imapConnection,
         $source_url = $php_self;
     }
 
-    if (!isset($msg)) {
-        $msg = '';
-    }
-    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' . "\n" .
-        '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
-        '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
-
     /*
      * This is the beginning of the message list table.
      * It wraps around all messages
      */
-    $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
-    $form_name = "FormMsgs" . $safe_name;
-    echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n"
-        . $moveFields . "\n";
 
     if (!empty($paginator) && !empty($msg_cnt_str)) {
 
@@ -727,7 +724,6 @@ function mail_message_listing_beginning ($imapConnection,
     /* line between header and button area */
         echo '</td></tr><tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
-        echo '<tr><td>';
         echo html_tag( 'tr' ) . "\n"
         . html_tag( 'td' ,'' , 'left', '', '' )
          . html_tag( 'table' ,'' , '', $color[9], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
@@ -743,11 +739,9 @@ function mail_message_listing_beginning ($imapConnection,
             echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";
             echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";
 
-  echo "      </small></td>\n"
+    echo "      </small></td>\n"
          . html_tag( 'td', '', 'right', '', 'nowrap' );
 
-
-
     if (!$auto_expunge) {
         echo getButton('SUBMIT', 'expungeButton',_("Expunge"))
              ."&nbsp;\n";
@@ -824,7 +818,6 @@ function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $colo
     /* End of message-list table */
 
     do_hook('mailbox_index_after');
-    echo "</form>\n";
 }
 
 function printHeader($mailbox, $sort, $color, $showsort=true) {
@@ -961,7 +954,7 @@ function get_selectall_link($start_msg, $sort) {
         } else {
             $result .= _("Select All");
         }
-        $result .= "</A>\n";
+        $result .= "</a>\n";
     }
 
     /* Return our final result. */
