@@ -5,9 +5,9 @@
  *
  * Prints the page header (duh)
  *
- * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: page_header.php,v 1.148.2.27 2006/06/14 14:25:41 indiri69 Exp $
+ * @version $Id: page_header.php 12153 2007-01-19 23:21:21Z pdontthink $
  * @package squirrelmail
  */
 
@@ -88,7 +88,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
            $compose_new_win, $compose_width, $compose_height,
            $attachemessages, $provider_name, $provider_uri,
            $javascript_on, $default_use_mdn, $mdn_user_support,
-           $startMessage;
+           $startMessage, $org_title;
 
     sqgetGlobalVar('base_uri', $base_uri, SQ_SESSION );
     sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION );
@@ -136,11 +136,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
             if($default_use_mdn && $mdn_user_support) {
                 $js .= "function sendMDN() {\n".
                          "    mdnuri=window.location+'&sendreceipt=1';\n" .
-                         "    if (window.top != window.self) {\n" .
-                         "      var newwin = window.open(mdnuri,'right');\n" .
-                         "    } else {\n " .
-                         "      var newwin = window.location = mdnuri;\n" .
-                         "    }\n" .
+                         "    window.location = mdnuri;\n" .
                        "\n}\n\n";
             }
 
@@ -150,7 +146,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
                       "\n<!--\n" . $js . "// -->\n</script>\n";
             }
 
-            displayHtmlHeader ('SquirrelMail', $js);
+            displayHtmlHeader($org_title, $js);
             $onload = $xtra;
           break;
         case 'src/compose.php':
@@ -195,7 +191,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
             $js .= "// -->\n".
                  "</script>\n";
             $onload = 'onload="checkForm();"';
-            displayHtmlHeader ('SquirrelMail', $js);
+            displayHtmlHeader($org_title, $js);
             break;
 
         default:
@@ -245,11 +241,11 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
 
 
         $onload = 'onload="checkForm();"';
-        displayHtmlHeader ('SquirrelMail', $js);
+        displayHtmlHeader($org_title, $js);
       } // end switch module
     } else {
         // JavaScript off
-        displayHtmlHeader ('SquirrelMail');
+        displayHtmlHeader($org_title);
         $onload = '';
     }
 
