@@ -3,12 +3,12 @@
 /**
  * move_messages.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Enables message moving between folders on the IMAP server.
  *
- * $Id: move_messages.php,v 1.81.2.11 2006/05/13 20:01:15 tokul Exp $
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: move_messages.php 12127 2007-01-13 20:07:24Z kink $
+ * @package squirrelmail
  */
 
 /* Path for SquirrelMail required files. */
@@ -29,7 +29,7 @@ if ( !sqgetGlobalVar('composesession', $composesession, SQ_SESSION) ) {
 
 function attachSelectedMessages($msg, $imapConnection) {
     global $username, $attachment_dir, $startMessage,
-           $data_dir, $composesession, $uid_support,
+           $data_dir, $composesession, $uid_support, $mailbox,
        $msgs, $thread_sort_messages, $allow_server_sort, $show_num,
        $compose_messages;
 
@@ -66,18 +66,19 @@ function attachSelectedMessages($msg, $imapConnection) {
     while ($j < count($msg)) {
         if (isset($msg[$i])) {
             $id = $msg[$i];
+            
             $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
-
+            
             if ($response == 'OK') {
+                $message = sqimap_get_message($imapConnection, $id, $mailbox);
 
-                // fetch the subject for the message with $id from msgs.
-                // is there a more efficient way to do this?
-                foreach($msgs as $k => $vals) {
-                    if($vals['ID'] == $id) {
-                        $subject = $msgs[$k]['SUBJECT'];
-                        break;
-                    }
+                // fetch the subject for the message from the object
+                $filename = $message->rfc822_header->subject;
+                if ( empty($filename) ) {
+                    $filename = "untitled-".$message->entity_id;
                 }
+                $filename .= '.msg';
+                $filename = decodeHeader($filename, false, false);
 
                 array_shift($body_a);
                 array_pop($body_a);
@@ -86,11 +87,15 @@ function attachSelectedMessages($msg, $imapConnection) {
 
                 $localfilename = GenerateRandomString(32, 'FILE', 7);
                 $full_localfilename = "$hashed_attachment_dir/$localfilename";
+                while (file_exists($full_localfilename)) {
+                    $localfilename = GenerateRandomString(32, 'FILE', 7);
+                    $full_localfilename = "$hashed_attachment_dir/$localfilename";
+                }
 
                 $fp = fopen( $full_localfilename, 'wb');
                 fwrite ($fp, $body);
                 fclose($fp);
-                $composeMessage->initAttachment('message/rfc822',$subject.'.msg',
+                $composeMessage->initAttachment('message/rfc822',$filename,
                      $full_localfilename);
             }
             $j++;
@@ -252,4 +257,4 @@ if ($exception) {
     exit;
 }
 ?>
-</BODY></HTML>
\ No newline at end of file
+</BODY></HTML>
